@@ -10,9 +10,9 @@ use JSON;
 
 our @ISA = qw(Exporter);
 
-our @EXPORT = qw(new geocode parse);
+our @EXPORT = qw(geocode parse);
 
-our $VERSION = 1.15;
+our $VERSION = 1.16;
 
 =head1 NAME
 
